@@ -26,8 +26,10 @@ pub(crate) const DYSFUNCTION_MSG_PRIORITY: i32 = 2;
 pub(crate) const BACKPRESSURE_MSG_PRIORITY: i32 = 0;
 // not maintaining network structure, so can wait
 pub(crate) const NODE_DATA_MSG_PRIORITY: i32 = -6;
+#[cfg(any(feature = "chunks", feature = "registers"))]
 // has payment throttle, but is not critical for network function
 pub(crate) const SERVICE_CMD_PRIORITY: i32 = -8;
+#[cfg(any(feature = "chunks", feature = "registers"))]
 // has no throttle and is sent by clients, lowest prio
 pub(crate) const SERVICE_QUERY_PRIORITY: i32 = -10;
 
@@ -46,6 +48,7 @@ use super::{
 #[derive(PartialEq, Debug, Clone)]
 #[allow(clippy::large_enum_variant)]
 pub enum MsgType {
+    #[cfg(any(feature = "chunks", feature = "registers"))]
     /// Service message
     Service {
         /// Message ID
@@ -104,7 +107,7 @@ impl MsgType {
                 ..
             } => JOIN_RESPONSE_PRIORITY,
 
-            // Inter-node comms for joining, relocating etc.
+            // Inter-node comms for joining, relocating, section handover votes etc.
             MsgType::System {
                 msg:
                     SystemMsg::Relocate(_)
@@ -112,8 +115,9 @@ impl MsgType {
                     | SystemMsg::JoinAsRelocatedRequest(_)
                     | SystemMsg::Propose { .. }
                     | SystemMsg::StartConnectivityTest(_)
-                    | SystemMsg::MembershipVote(_)
-                    | SystemMsg::MembershipAE(_),
+                    | SystemMsg::MembershipVotes(_)
+                    | SystemMsg::MembershipAE(_)
+                    | SystemMsg::HandoverVote(_),
                 ..
             } => JOIN_RELOCATE_MSG_PRIORITY,
 
@@ -131,21 +135,28 @@ impl MsgType {
             } => BACKPRESSURE_MSG_PRIORITY,
 
             // Inter-node comms related to processing client requests
+            MsgType::System {
+                msg: SystemMsg::NodeMsgError { .. },
+                ..
+            } => NODE_DATA_MSG_PRIORITY,
+            // Inter-node comms related to processing client requests
+            #[cfg(any(feature = "chunks", feature = "registers"))]
             MsgType::System {
                 msg:
                     SystemMsg::NodeCmd(_)
                     | SystemMsg::NodeEvent(NodeEvent::CouldNotStoreData { .. })
                     | SystemMsg::NodeQuery(_)
-                    | SystemMsg::NodeQueryResponse { .. }
-                    | SystemMsg::NodeMsgError { .. },
+                    | SystemMsg::NodeQueryResponse { .. },
                 ..
             } => NODE_DATA_MSG_PRIORITY,
 
             // Client <-> node service comms
+            #[cfg(any(feature = "chunks", feature = "registers"))]
             MsgType::Service {
                 msg: ServiceMsg::Cmd(_),
                 ..
             } => SERVICE_CMD_PRIORITY,
+            #[cfg(any(feature = "chunks", feature = "registers"))]
             MsgType::Service { .. } => SERVICE_QUERY_PRIORITY,
         }
     }
